# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).


## [0.1.0] - 2023-10-31

Initial release

## [0.1.1] - 2023-10-31

### Fixed

- `AsyncOpenAQ` client `close()` method. 